// ---------------------------------------------------------------------------
#ifndef SDKFLASHH
#define SDKFLASHH
// ________________________________________________________________________________________________________________________________

#include <windows.h>
// ________________________________________________________________________________________________________________________________

#define CBAPI               cdecl
#define WM_ONSCANNERSTATUS 	(WM_USER + 301)
#define WM_ONSCANNERNOTIFY 	(WM_USER + 302)


typedef unsigned short 		PIXEL_FORMAT;


typedef void(cdecl*TOnScannerStatusEvent)(int scannerStatus);
typedef void(cdecl*TOnScannerNotifyEvent)(int scannerNotify);

typedef enum EIPSize : 		   signed	long {
	eisNone = -1,				// no ip
	eis35x43 = 0,				// 35x43
	eis25x30,  					// reserved
	eis24x30,					// 24x30
	eis18x24,					// 18x24
	eisReserved,				// reserved
	eisTotal,					// reserved
} EIPSize;

typedef enum EScanResolution : unsigned long {
	esr100 = 0,				// 100um
	esr200,					// 200um
} EScanResolution;

typedef enum EConnectionType : unsigned long {
	ectNone,				//not conected
	ectEthernet,			// ethernet
	ectUSB,					// USB
} EConnectionType;

typedef enum EScannerStatus : unsigned long {
	estNone,				//none
	estDisconnected,		// not connect
	estWaiting,				// try to connection and wait until connection
	estWarmUp, 				// connected but not ready
	estErasing,				// erasing after scanning
	estScannerReady,		// scanner is ready except ip
	estReadyForScan,		// can run scanning
	estTransferring,		// scanning or transferring data
} EScannerStatus;

typedef enum EScannerError : unsigned long {
	eseOk,						//no error
	eseScanningTimeOut	= 1,	//scanning timeout
	eseErasingTimeOut	= 2,	//erasing  timeout
	eseNoMovingPlate	= 4,	// no movingplate
	eseRPMError			= 8,	// rpm error						reserved
	esePSDError			= 16,	// psd error						reserved
	eseAlignTimeout		= 32,	// align timeout					reserved
	eseLaserTempError	= 64,	// laser temperature is too hot		reserved
	eseEraseTempError	= 128,	// eraser temperature is too hot	reserved
	eseDuplicateSDK		= 65536,// sdk is already running
} EScannerError;

typedef enum EScannerNotify : unsigned long {
	esnNone,				// none
	esnScanStarted,			// scanning is srtared
	esnProgress,			//  transferring progress is changed
	esnPreprocessed,		//  image is ready
	esnChangeFormat,		// ip size of resolution is changed
	esnScannerError,		// error is occurred
	esnParitalData,			// for testing in factory.
} EScannerNotify;

typedef enum EScannerModel : unsigned long {
	esmFlash30 = 0,			//FireCR Flash30
	esmFlash50 = 1,			//FireCR Flash50
	esmFlash70 = 2			//FireCR Flash70
}EScannerModel;

typedef struct TCallBackSet {
	TOnScannerStatusEvent scannerStatusEvent;
	TOnScannerNotifyEvent scannerNotifyEvent;
	void* dummy;								//for test
} TCallBackSet, *PCallBackSet;

typedef struct TScannerInfo {
	char nick[16];
	char PN[20];
	union {							// ip address
		int quad;
		char bytes[4];
	}
	IPAddress;
	EConnectionType ConnectionType;	//usb etehrnet
	EScannerModel	model;			// 30,50,70
} TScannerInfo;
// ________________________________________________________________________________________________________________________________
#ifdef __cplusplus

extern "C" {
#endif
	__declspec(dllexport) BOOL CBAPI flOpenScannerSDK(HWND hwnd,	TCallBackSet* callbackSet, wchar_t* configPath);
	__declspec(dllexport) void CBAPI flCloseScannerSDK();
	__declspec(dllexport) BOOL CBAPI flOpenScanner();
	__declspec(dllexport) void CBAPI flCloseScanner();

	__declspec(dllexport) BOOL CBAPI flGetImageFromList(int index);
	__declspec(dllexport) void CBAPI flGetScannerInfo(TScannerInfo* info);
	__declspec(dllexport) void CBAPI flGetImageSize(int* width, int* height);
	__declspec(dllexport) PIXEL_FORMAT * CBAPI flGetImageBuffer();
	__declspec(dllexport) float* CBAPI flGetImageBufferFloat();

	__declspec(dllexport) BOOL CBAPI flShowModalCalibrationDialog(BOOL visible);
	__declspec(dllexport) BOOL CBAPI flShowScannerControlDialog(BOOL visible);

	__declspec(dllexport) int CBAPI flGetProgress();
	__declspec(dllexport) EScannerStatus CBAPI flGetScannerStatus();
	__declspec(dllexport) EScanResolution CBAPI flGetResolution();
	__declspec(dllexport) EIPSize CBAPI flGetIPSize();

	__declspec(dllexport) EConnectionType CBAPI flGetScannerConnectionType();
	__declspec(dllexport) long CBAPI flGetScannerError();
	__declspec(dllexport) BOOL CBAPI flDoRun();
	__declspec(dllexport) BOOL CBAPI flDoErase();
	__declspec(dllexport) void CBAPI flSetResolution(EScanResolution res);
	__declspec(dllexport) void CBAPI flDoStop();
	__declspec(dllexport) BOOL CBAPI flIsCalibrated();
	__declspec(dllexport) void CBAPI QuadraticRegression(double &a, double &b, double &c, int* srcx, int* srcy, int count);
	__declspec(dllexport) int CBAPI flGetDoseLevelWith(int intensity);
#ifdef __cplusplus
}
#endif
// ________________________________________________________________________________________________________________________________

typedef BOOL(CBAPI * FLOPENSCANNERSDK)(HWND hwnd, TCallBackSet * callbackSet,	wchar_t* configPath);
typedef void(CBAPI * FLCLOSESCANNERSDK)();
typedef BOOL(CBAPI * FLOPENSCANNER)();
typedef void(CBAPI * FLCLOSESCANNER)();

typedef BOOL(CBAPI * FLGETIMAGEFROMLIST)(int index);
typedef void(CBAPI * FLGETSCANNERINFO)(TScannerInfo* info);
typedef void(CBAPI * FLGETIMAGESIZE)(int* width, int* height);
typedef PIXEL_FORMAT* (CBAPI* FLGETIMAGEBUFFER)();
typedef float* (CBAPI* FLGETIMAGEBUFFERFLOAT)();
typedef BOOL(CBAPI * FLSHOWMODALCALIBRATIONDIALOG)(BOOL visible);
typedef BOOL(CBAPI * FLSHOWSCANNERCONTROLDIALOG)(BOOL visible);

typedef int(CBAPI * FLGETPROGRESS)();
typedef EScannerStatus(CBAPI* FLGETSCANNERSTATUS)();
typedef EScanResolution(CBAPI* FLGETRESOLUTION)();
typedef EIPSize(CBAPI* FLGETIPSIZE)();

typedef EConnectionType(CBAPI* FLGETSCANNERCONNECTIONTYPE)();
typedef long(CBAPI* FLGETSCANNERERROR)();

typedef BOOL(CBAPI * FLDORUN)();
typedef BOOL(CBAPI * FLDOERASE)();
typedef void(CBAPI * FLSETRESOLUTION)(EScanResolution res);
typedef void(CBAPI * FLDOSTOP)();
typedef BOOL(CBAPI * FLISCALIBRATED)();

typedef void (CBAPI* FLQUADRATICREGRESSION)(double &a, double &b, double &c, int* srcx, int* srcy, int count);
typedef int	(CBAPI FLGETDOSELEVELWIDTH)(int intensity);
// ________________________________________________________________________________________________________________________________
#endif

